@@ -1,5 +1,5 @@
 package File::Find::Object::Rule::VCS;
-$File::Find::Object::Rule::VCS::VERSION = '0.0.4';
+$File::Find::Object::Rule::VCS::VERSION = '0.0.5';
 
 use 5.008;
 
@@ -108,7 +108,7 @@ Systems
 
 =head1 VERSION
 
-version 0.0.4
+version 0.0.5
 
 =head1 SYNOPSIS
 
@@ -154,10 +154,6 @@ ignore methods
 
 =back
 
-=head1 VERSION
-
-version 0.0.4
-
 =head1 METHODS
 
 =head2 ignore_vcs
@@ -220,14 +216,6 @@ from your L<File::Find::Object::Rule> search.
 
 - Add other useful VCS-related methods
 
-=head1 SUPPORT
-
-Bugs should always be submitted via the CPAN bug tracker
-
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=File-Find-Rule-VCS>
-
-For other issues, contact the maintainer
-
 =head1 AUTHOR
 
 =head2 ORIGINAL AUTHOR
@@ -259,36 +247,10 @@ LICENSE file included with this module.
 
 Modified by Shlomi Fish, 2009. All rights disclaimed.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2018 by Shlomi Fish.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/file-find-object-rule-vcs/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc File::Find::Object::Rule::VCS
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -306,14 +268,6 @@ L<https://metacpan.org/release/File-Find-Object-Rule-VCS>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/File-Find-Object-Rule-VCS>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -322,22 +276,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=File-Find-Object-Rule-VCS>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/File-Find-Object-Rule-VCS>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/File-Find-Object-Rule-VCS>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -386,4 +324,24 @@ L<https://github.com/shlomif/file-find-object-rule-vcs>
 
   git clone http://svn.berlios.de/svnroot/repos/web-cpan/File-Find-Object/
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/file-find-object-rule-vcs/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2020 by Shlomi Fish.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
